import { ScanOptions, ScanResults } from "./types";
import { runGitleaksScan, scanRemoteRepository, scanGitHistory } from "./gitleaks";
/**
 * Initialize the WebAssembly module and Python environment
 */
export declare function initialize(): Promise<void>;
/**
 * Scan a file or string content for secrets
 * @param content The file content to scan
 * @param filePath The path of the file (for reporting)
 * @param options Scan options
 * @returns Scan results
 */
export declare function scanContent(content: string, filePath: string, options?: Partial<ScanOptions>): Promise<ScanResults>;
/**
 * Scan a file for secrets
 * @param filePath The path of the file to scan
 * @param options Scan options
 * @returns Scan results
 */
export declare function scanFile(filePath: string, options?: Partial<ScanOptions>): Promise<ScanResults>;
/**
 * Scan a directory for secrets
 * @param directory The directory to scan
 * @param options Scan options
 * @returns Scan results
 */
export declare function scanDirectory(directory?: string, options?: Partial<ScanOptions>): Promise<ScanResults>;
/**
 * Scan a directory using both detect-secrets and Gitleaks
 * @param directory The directory to scan
 * @param options Scan options
 * @returns Combined scan results
 */
export declare function scanWithBothScanners(directory?: string, options?: Partial<ScanOptions>): Promise<ScanResults>;
declare const _default: {
    initialize: typeof initialize;
    scanContent: typeof scanContent;
    scanFile: typeof scanFile;
    scanDirectory: typeof scanDirectory;
    scanWithBothScanners: typeof scanWithBothScanners;
    runGitleaksScan: typeof runGitleaksScan;
    scanRemoteRepository: typeof scanRemoteRepository;
    scanGitHistory: typeof scanGitHistory;
};
export default _default;
